@@ -559,7 +559,7 @@ class Iterable(list):
     Class to iterate among returned objects.
     """
 
-    def __init__(self, cls, lst, attr):
+    def __init__(self, cls, lst, attr=None):
         self._list = lst
         self._index = len(lst)
         self._class = cls
@@ -1082,11 +1082,12 @@ class Index(object):
                 url = "%s/%s" % (url, item.id)
             elif key and not value:
                 key = smart_quote(key)
-                url = "%s/%s" % (self.template.replace("{key}", key), item.id)
+                url = "%s/%s" % (self.template.replace("{key}/{value}", key),
+                                 item.id)
             elif not key and not value:
                 url = self.template.replace("{key}/{value}", item.id)
             else:
-                raise TypeError("remove() take at least 2 arguments, the " \
+                raise TypeError("delete() takes at least 2 arguments, the " \
                                 "key of the index and the %s to remove"
                                 % self._index_for)
         response, content = Request().delete(url)
@@ -1094,8 +1095,8 @@ class Index(object):
             if options.SMART_ERRORS:
                 raise KeyError(self._index_for.capitalize())
             else:
-                raise NotFoundError(response.status,
-                                    "%s not found" % self._index_for.capitalize())
+                index_for = self._index_for.capitalize()
+                raise NotFoundError(response.status, "%s not found" % index_for)
         elif response.status != 204:
             raise StatusException(response.status)
 
@@ -1279,25 +1280,23 @@ class Path(object):
     """
 
     def __init__(self, dic):
-        self.start = property(Node(dic["start"]))
-        self.end = property(Node(dic["end"]))
-        self.weight = property(dic.get("weight", None))
+        self._dic = dic
         self._length = int(dic["length"])
-        nodes = []
-        relationships = []
+        self._nodes = []
+        self._relationships = []
         self._iterable = []
+        self._start = Node(self._dic["start"])
+        self._end = Node(self._dic["end"])
         for i in range(0, len(dic["relationships"])):
             node = Node(dic["nodes"][i])
-            nodes.append(node)
+            self._nodes.append(node)
             relationship = Relationship(dic["relationships"][i])
-            relationships.append(node)
+            self._relationships.append(relationship)
             self._iterable.append(node)
             self._iterable.append(relationship)
         node = Node(dic["nodes"][-1])
-        nodes.append(node)
+        self._nodes.append(node)
         self._iterable.append(node)
-        self.nodes = property(nodes)
-        self.relationships = property(relationships)
 
     def __len__(self):
         return self._length
@@ -1307,6 +1306,26 @@ class Path(object):
             for obj in self._iterable:
                 yield obj
 
+    def _get_start(self):
+        return self._start
+    start = property(_get_start)
+
+    def _get_end(self):
+        return self._end
+    end = property(_get_end)
+
+    def _get_weight(self):
+        return self._dic.get("weight", None)
+    weight = property(_get_weight)
+
+    def _get_nodes(self):
+        return self._get_nodes
+    nodes = property(_get_nodes)
+
+    def _get_relationships(self):
+        return self._relationships
+    relationships = property(_get_relationships)
+
 
 class Position(object):
     """
@@ -1314,11 +1333,28 @@ class Position(object):
     """
 
     def __init__(self, dic):
-        self.node = property(Node(dic["node"]))
-        self.depth = int(dic["depth"])
-        relationship = Relationship(dic["last relationship"])
-        self.last_relationship = property(relationship)
-        self.path = property(Path(dic["path"]))
+        self._node = Node(dic["node"])
+        self._depth = int(dic["depth"])
+        relationship = Relationship(dic.get("last relationship",
+                                    dic.get("last_relationship", None)))
+        self._last_relationship = relationship
+        self._path = Path(dic["path"])
+
+    def _get_node(self):
+        return self._node
+    node = property(_get_node)
+
+    def _get_depth(self):
+        return self._depth
+    depth = property(_get_depth)
+
+    def _get_last_relationship(self):
+        return self._last_relationship
+    last_relationship = property(_get_last_relationship)
+
+    def _get_path(self):
+        return self._path
+    path = property(_get_path)
 
 
 class BaseInAndOut(object):
@@ -1442,27 +1478,40 @@ class Extension(object):
             raise NotFoundError(response.status, "Unable get extension")
 
     def __call__(self, *args, **kwargs):
+        # The returns param is a temporary solution while
+        # a proper way to get the data type of returned values by
+        # the extensions is implemented in Neo4j
+        returns = kwargs.pop("returns", None)
         parameters = self._parse_parameters(args, kwargs)
         response, content = Request().post(self.url, data=parameters)
         if response.status == 200:
-            results_list = json.loads(content)
-            # The returns param is a temporary solution while
-            # a proper way to get the data type of returned values by
-            # the extensions is implemented in Neo4j
-            returns = kwargs.pop("returns", None)
+            result = json.loads(content)
             # Another option is to inspect the results
-            if (not returns and isinstance(results_list, (tuple, list))
-                and len(results_list) > 0):
-                returns = results_list[0].get("self", None)
-            if results_list and returns:
+            if not returns:
+                if isinstance(result, (tuple, list)) and len(result) > 0:
+                    returns = result[0].get("self", None)
+                elif isinstance(result, dict) and "self" in result:
+                    returns = result.get("self", None)
+            if isinstance(result, (tuple, list)) and returns:
                 if NODE in returns:
-                    return Iterable(Node, results_list, "self")
+                    return Iterable(Node, result, "self")
                 elif RELATIONSHIP in returns:
-                    return Iterable(Relationship, results_list, "self")
-                elif PATH in returns:
-                    return Iterable(Path, results_list)
+                    return Iterable(Relationship, result, "self")
+                elif PATH in returns or FULLPATH in returns:
+                    return Iterable(Path, result)
                 elif POSITION in returns:
-                    return Iterable(Position, results_list)
+                    return Iterable(Position, result)
+            if isinstance(result, dict) and returns:
+                if NODE in returns:
+                    return Node(result["self"], data=result)
+                elif RELATIONSHIP in returns:
+                    return Relationship(result["self"], data=result)
+                elif PATH in returns:
+                    return Path(result)
+                elif POSITION in returns:
+                    return Position(result)
+            elif result:
+                return result
             else:
                 return []
         elif response.status == 404:
