@@ -279,6 +279,13 @@ class IndexesTestCase(RelationshipsTestCase):
         index.delete("surnames", "d", n1)
         self.assertTrue(n1 not in index["surnames"]["d"])
 
+    def test_delete_node_from_index_with_no_value(self):
+        n1 = self.gdb.nodes.create(name="John Doe", place="Texas")
+        index = self.gdb.nodes.indexes.create(name="doe")
+        index["surnames"]["d"] = n1
+        index.delete("surnames", None, n1)
+        self.assertTrue(n1 not in index["surnames"]["d"])
+
     def test_delete_relationship_from_index(self):
         n1 = self.gdb.nodes.create(name="John Doe", place="Texas")
         n2 = self.gdb.nodes.create(name="Michael Doe", place="Tijuana")
@@ -310,11 +317,11 @@ class IndexesTestCase(RelationshipsTestCase):
         self.assertTrue(n1 in results and n2 in results)
         results = index.query("surnames:do*")
         self.assertTrue(n1 in results and n2 in results)
-        results = index.query('surnames', Q('do*'))
+        results = index.query('surnames', Q('do*', wildcard=True))
         self.assertTrue(n1 in results and n2 in results)
-        results = index.query(Q('surnames', 'do*'))
+        results = index.query(Q('surnames', 'do*', wildcard=True))
         self.assertTrue(n1 in results and n2 in results)
-        results = index.query(Q('surnames', 'do*') & Q('place', 'Tijuana'))
+        results = index.query(Q('surnames', 'do*', wildcard=True) & Q('place', 'Tijuana'))
         self.assertTrue(n1 not in results and n2 in results)
         results = index.query(-Q('surnames', 'donald') | +Q('place', 'Texas'))
         self.assertTrue(n2 not in results and n1 in results)
@@ -450,6 +457,45 @@ class ExtensionsTestCase(TraversalsTestCase):
             fail = True
         self.assertTrue(not fail)
 
+    def test_gremlin_extension_reference_node(self):
+        # Assuming the GremlinPlugin installed
+        ext = self.gdb.extensions.GremlinPlugin
+        n = ext.execute_script(script='g.v(0)')
+        self.assertTrue(isinstance(n, client.Node))
+
+    def test_gremlin_extension_reference_node_returns(self):
+        # Assuming the GremlinPlugin installed
+        ext = self.gdb.extensions.GremlinPlugin
+        n = ext.execute_script(script='g.v(0)', returns=constants.NODE)
+        self.assertTrue(isinstance(n, client.Node))
+
+    def test_gremlin_extension_relationships(self):
+        # Assuming the GremlinPlugin installed
+        n1 = self.gdb.nodes.create()
+        n2 = self.gdb.nodes.create()
+        n3 = self.gdb.nodes.create()
+        r1 = n1.relationships.create("related", n2)
+        r2 = n1.relationships.create("related", n3)
+        gremlin = self.gdb.extensions.GremlinPlugin.execute_script
+        rels = gremlin(script='g.v(%s).outE' % n1.id)
+        self.assertEqual(len(rels), 2)
+        for rel in rels:
+            self.assertTrue(isinstance(rel, client.Relationship))
+
+    def test_gremlin_extension_relationships_returns(self):
+        # Assuming the GremlinPlugin installed
+        n1 = self.gdb.nodes.create()
+        n2 = self.gdb.nodes.create()
+        n3 = self.gdb.nodes.create()
+        r1 = n1.relationships.create("related", n2)
+        r2 = n1.relationships.create("related", n3)
+        gremlin = self.gdb.extensions.GremlinPlugin.execute_script
+        rels = gremlin(script='g.v(%s).outE' % n1.id,
+                       returns=constants.RELATIONSHIP)
+        self.assertEqual(len(rels), 2)
+        for rel in rels:
+            self.assertTrue(isinstance(rel, client.Relationship))
+
 
 class TransactionsTestCase(ExtensionsTestCase):
 
